@@ -4,6 +4,7 @@ from typing import Optional
 import annofabcli
 import annofabcli.annotation_specs.list_annotation_specs_history
 import annofabcli.annotation_specs.list_annotation_specs_label
+import annofabcli.annotation_specs.list_attribute_restriction
 import annofabcli.annotation_specs.print_label_color
 import annofabcli.common.cli
 
@@ -13,6 +14,7 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
+    annofabcli.annotation_specs.list_attribute_restriction.add_parser(subparsers)
     annofabcli.annotation_specs.list_annotation_specs_history.add_parser(subparsers)
     annofabcli.annotation_specs.list_annotation_specs_label.add_parser(subparsers)
     annofabcli.annotation_specs.print_label_color.add_parser(subparsers)
