@@ -239,6 +239,9 @@ class Task:
             # タスクの状態
             "inspection_is_skipped",
             "acceptance_is_skipped",
+            "diff_days_to_first_inspection_started",
+            "diff_days_to_first_acceptance_started",
+            "diff_days_to_first_acceptance_completed",
         ]
 
         print_csv(self.df[columns], str(output_file))
