@@ -111,15 +111,20 @@ class UserPerformance:
 
     @classmethod
     def from_df(
-        cls, df_task_history: pandas.DataFrame, df_labor: pandas.DataFrame, df_worktime_ratio: pandas.DataFrame
+        cls,
+        df_task_history: pandas.DataFrame,
+        df_worktime_ratio: pandas.DataFrame,
+        df_labor: Optional[pandas.DataFrame] = None,
     ) -> UserPerformance:
         """
         AnnoWorkの実績時間から、作業者ごとに生産性を算出する。
 
         Args:
             df_task_history: タスク履歴のDataFrame
-            df_labor: 実績作業時間のDataFrame
-            df_worktime_ratio: 作業したタスク数を、作業時間で按分した値が格納されたDataFrame
+            df_worktime_ratio: 作業したタスク数を、作業時間で按分した値が格納されたDataFrame. 以下の列を参照する。
+                account_id, phase, worktime_hour
+            df_labor: 実績作業時間のDataFrame。以下の列を参照する
+                actual_worktime_hour, date, account_id
 
         Returns:
 
@@ -134,13 +139,13 @@ class UserPerformance:
             return phase_list
 
         df_agg_task_history = df_task_history.pivot_table(
-            values="worktime_hour", columns="phase", index="user_id", aggfunc=numpy.sum
+            values="worktime_hour", columns="phase", index="account_id", aggfunc=numpy.sum
         ).fillna(0)
 
-        if len(df_labor) > 0:
-            df_agg_labor = df_labor.pivot_table(values="actual_worktime_hour", index="user_id", aggfunc=numpy.sum)
+        if df_labor is not None and len(df_labor) > 0:
+            df_agg_labor = df_labor.pivot_table(values="actual_worktime_hour", index="account_id", aggfunc=numpy.sum)
             df_tmp = df_labor[df_labor["actual_worktime_hour"] > 0].pivot_table(
-                values="date", index="user_id", aggfunc=numpy.max
+                values="date", index="account_id", aggfunc=numpy.max
             )
             if len(df_tmp) > 0:
                 df_agg_labor["last_working_date"] = df_tmp
@@ -173,7 +178,7 @@ class UserPerformance:
                 "rejected_count",
             ],
             columns="phase",
-            index="user_id",
+            index="account_id",
             aggfunc=numpy.sum,
         ).fillna(0)
 
@@ -193,11 +198,9 @@ class UserPerformance:
         df = df.drop(dropped_column, axis=1)
 
         # ユーザ情報を取得
-        df_user = df_task_history.groupby("user_id").first()[["username", "biography"]]
-        df_user.columns = pandas.MultiIndex.from_tuples([("username", ""), ("biography", "")])
+        df_user = df_task_history.groupby("account_id").first()[["user_id", "username", "biography"]]
+        df_user.columns = pandas.MultiIndex.from_tuples([("user_id", ""), ("username", ""), ("biography", "")])
         df = df.join(df_user)
-        df[("user_id", "")] = df.index
-
         return cls(df)
 
     @classmethod
@@ -310,9 +313,7 @@ class UserPerformance:
         print_csv(self.df[columns], str(output_file))
 
     @staticmethod
-    def _plot_average_line(fig: bokeh.plotting.Figure, value: Optional[float], dimension: str):
-        if value is None:
-            return
+    def _plot_average_line(fig: bokeh.plotting.Figure, value: float, dimension: str):
         span_average_line = bokeh.models.Span(
             location=value,
             dimension=dimension,
@@ -322,9 +323,14 @@ class UserPerformance:
         fig.add_layout(span_average_line)
 
     @staticmethod
-    def _plot_quartile_line(fig: bokeh.plotting.Figure, quartile: Optional[tuple[float, float, float]], dimension: str):
-        if quartile is None:
-            return
+    def _plot_quartile_line(fig: bokeh.plotting.Figure, quartile: tuple[float, float, float], dimension: str):
+        """
+
+        Args:
+            fig (bokeh.plotting.Figure):
+            quartile (tuple[float, float, float]): 四分位数。tuple[25%値, 50%値, 75%値]
+            dimension (str): [description]: width or height
+        """
 
         for value in quartile:
             span_average_line = bokeh.models.Span(
@@ -464,14 +470,18 @@ class UserPerformance:
                 )
 
         for fig, phase in zip(figure_list, self.phase_list):
-            average_value = self._get_average_value(
+            average_hour = self._get_average_value(
                 df,
                 numerator_column=(f"{worktime_type.value}_worktime_hour", phase),
                 denominator_column=("annotation_count", phase),
             )
-            self._plot_average_line(fig, average_value, dimension="width")
-            quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime_hour/annotation_count", phase))
-            self._plot_quartile_line(fig, quartile, dimension="width")
+            if average_hour is not None:
+                average_minute = average_hour * 60
+                self._plot_average_line(fig, average_minute, dimension="width")
+
+            quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime_minute/annotation_count", phase))
+            if quartile is not None:
+                self._plot_quartile_line(fig, quartile, dimension="width")
 
         for fig, phase in zip(figure_list, self.phase_list):
             tooltip_item = [
@@ -575,14 +585,16 @@ class UserPerformance:
             average_value = self._get_average_value(
                 df, numerator_column=(column_pair[0], phase), denominator_column=(column_pair[1], phase)
             )
-            self._plot_average_line(fig, average_value, dimension="width")
+            if average_value is not None:
+                self._plot_average_line(fig, average_value, dimension="width")
 
         for column, fig in zip(
             ["rejected_count/task_count", "pointed_out_inspection_comment_count/annotation_count"],
             figure_list,
         ):
             quartile = self._get_quartile_value(df, (column, phase))
-            self._plot_quartile_line(fig, quartile, dimension="width")
+            if quartile is not None:
+                self._plot_quartile_line(fig, quartile, dimension="width")
 
         for fig in figure_list:
             tooltip_item = [
@@ -630,6 +642,75 @@ class UserPerformance:
         作業時間を元に算出した生産性と品質の関係を、メンバごとにプロットする
         """
 
+        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
+            return figure(
+                plot_width=self.PLOT_WIDTH,
+                plot_height=self.PLOT_HEIGHT,
+                title=title,
+                x_axis_label=x_axis_label,
+                y_axis_label=y_axis_label,
+            )
+
+        def plot_average_and_quartile_line():
+            x_average_hour = self._get_average_value(
+                df,
+                numerator_column=(f"{worktime_type.value}_worktime_hour", phase),
+                denominator_column=("annotation_count", phase),
+            )
+            x_average_minute = x_average_hour * 60 if x_average_hour is not None else None
+
+            for column_pair, fig in zip(
+                [("rejected_count", "task_count"), ("pointed_out_inspection_comment_count", "annotation_count")],
+                figure_list,
+            ):
+                if x_average_minute is not None:
+                    self._plot_average_line(fig, x_average_minute, dimension="height")
+
+                y_average = self._get_average_value(
+                    df,
+                    numerator_column=(column_pair[0], phase),
+                    denominator_column=(column_pair[1], phase),
+                )
+                if y_average is not None:
+                    self._plot_average_line(fig, y_average, dimension="width")
+
+            x_quartile = self._get_quartile_value(
+                df, (f"{worktime_type.value}_worktime_minute/annotation_count", phase)
+            )
+            for column, fig in zip(
+                ["rejected_count/task_count", "pointed_out_inspection_comment_count/annotation_count"],
+                figure_list,
+            ):
+                if x_quartile is not None:
+                    self._plot_quartile_line(fig, x_quartile, dimension="height")
+                y_quartile = self._get_quartile_value(df, (column, phase))
+                if y_quartile is not None:
+                    self._plot_quartile_line(fig, y_quartile, dimension="width")
+
+        def set_tooltip():
+            for fig in figure_list:
+                tooltip_item = [
+                    "user_id_",
+                    "username_",
+                    "biography_",
+                    f"{worktime_type.value}_worktime_hour_{phase}",
+                    f"task_count_{phase}",
+                    f"input_data_count_{phase}",
+                    f"annotation_count_{phase}",
+                    f"{worktime_type.value}_worktime_hour/input_data_count_{phase}",
+                    f"{worktime_type.value}_worktime_hour/annotation_count_{phase}",
+                    f"rejected_count_{phase}",
+                    f"pointed_out_inspection_comment_count_{phase}",
+                    f"rejected_count/task_count_{phase}",
+                    f"pointed_out_inspection_comment_count/annotation_count_{phase}",
+                ]
+                if worktime_type == WorktimeType.ACTUAL:
+                    tooltip_item.append("last_working_date_")
+
+                hover_tool = create_hover_tool(tooltip_item)
+                fig.add_tools(hover_tool)
+                self._set_legend(fig)
+
         if not self._validate_df_for_output(output_file):
             return
 
@@ -640,15 +721,6 @@ class UserPerformance:
                 df[(f"{worktime_type.value}_worktime_hour/annotation_count", phase)] * 60
             )
 
-        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
-            return figure(
-                plot_width=self.PLOT_WIDTH,
-                plot_height=self.PLOT_HEIGHT,
-                title=title,
-                x_axis_label=x_axis_label,
-                y_axis_label=y_axis_label,
-            )
-
         logger.debug(f"{output_file} を出力します。")
 
         figure_list = [
@@ -692,54 +764,8 @@ class UserPerformance:
                     color=get_color_from_palette(biography_index),
                 )
 
-        x_average_value = self._get_average_value(
-            df,
-            numerator_column=(f"{worktime_type.value}_worktime_hour", phase),
-            denominator_column=("annotation_count", phase),
-        )
-        for column_pair, fig in zip(
-            [("rejected_count", "task_count"), ("pointed_out_inspection_comment_count", "annotation_count")],
-            figure_list,
-        ):
-            self._plot_average_line(fig, x_average_value, dimension="height")
-            y_average_value = self._get_average_value(
-                df,
-                numerator_column=(column_pair[0], phase),
-                denominator_column=(column_pair[1], phase),
-            )
-            self._plot_average_line(fig, y_average_value, dimension="width")
-
-        x_quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime_hour/annotation_count", phase))
-        for column, fig in zip(
-            ["rejected_count/task_count", "pointed_out_inspection_comment_count/annotation_count"],
-            figure_list,
-        ):
-            self._plot_quartile_line(fig, x_quartile, dimension="height")
-            quartile = self._get_quartile_value(df, (column, phase))
-            self._plot_quartile_line(fig, quartile, dimension="width")
-
-        for fig in figure_list:
-            tooltip_item = [
-                "user_id_",
-                "username_",
-                "biography_",
-                f"{worktime_type.value}_worktime_hour_{phase}",
-                f"task_count_{phase}",
-                f"input_data_count_{phase}",
-                f"annotation_count_{phase}",
-                f"{worktime_type.value}_worktime_hour/input_data_count_{phase}",
-                f"{worktime_type.value}_worktime_hour/annotation_count_{phase}",
-                f"rejected_count_{phase}",
-                f"pointed_out_inspection_comment_count_{phase}",
-                f"rejected_count/task_count_{phase}",
-                f"pointed_out_inspection_comment_count/annotation_count_{phase}",
-            ]
-            if worktime_type == WorktimeType.ACTUAL:
-                tooltip_item.append("last_working_date_")
-
-            hover_tool = create_hover_tool(tooltip_item)
-            fig.add_tools(hover_tool)
-            self._set_legend(fig)
+        plot_average_and_quartile_line()
+        set_tooltip()
 
         div_element = self._create_div_element()
         div_element.text += """円の大きさ：作業時間<br>"""
