@@ -47,7 +47,9 @@ class ApiWithCreatingTask(Enum):
 
 def get_task_relation_dict(csv_file: Path) -> TaskInputRelation:
     """CSVから、keyがtask_id, valueがinput_data_idのlistのdictを生成します。"""
-    df = pandas.read_csv(str(csv_file), header=None, usecols=(0, 1), names=("task_id", "input_data_id"))
+
+    # `dtype=str`を指定した理由：指定しないと、IDが`001`のときに`1`に変換されてしまうため
+    df = pandas.read_csv(str(csv_file), header=None, usecols=(0, 1), names=("task_id", "input_data_id"), dtype=str)
     result: TaskInputRelation = defaultdict(list)
     for task_id, input_data_id in zip(df["task_id"], df["input_data_id"]):
         result[task_id].append(input_data_id)
@@ -250,7 +252,7 @@ def parse_args(parser: argparse.ArgumentParser):
         help=(
             "タスクに割り当てる入力データが記載されたCSVファイルのパスを指定してください。"
             "CSVのフォーマットは、以下の通りです。"
-            "タスク作成画面でアップロードするCSVと同じフォーマットです。"
+            "タスク作成画面でアップロードするCSVと同じフォーマットです。\n"
             "\n"
             " * ヘッダ行なし, カンマ区切り\n"
             " * 1列目: task_id\n"
